@@ -13,10 +13,7 @@ except Exception as e:
     print(e)
 
 
-sqlite_file = f'{os.path.abspath(os.path.dirname(__file__))}/notecoin.db'
-
-
-def backup_tables():
+def backup_tables(sqlite_file):
     tran = MySQLtoSQLite(
         mysql_database="notecoin",
         mysql_user=read_secret(cate1='notecoin', cate2='dataset', cate3='mysql', cate4='user'),
@@ -27,5 +24,3 @@ def backup_tables():
         sqlite_file=sqlite_file)
 
     tran.transfer()
-
-
