@@ -3,7 +3,6 @@ import logging
 import os
 from datetime import datetime, timedelta
 
-import pandas as pd
 from notecoin.base.database.lanzou import LanzouDirectory
 from notecoin.coins.base.load import LoadDataKline, LoadTradeKline
 from notecoin.utils.time import (day_during, month_during, week_during,
@@ -161,9 +160,16 @@ class DataFileProperty:
         [os.remove(csv) for csv in result]
         return True
 
+    def load_daily(self, start_time, end_time):
+        self.file_pro.start_date, self.file_pro.end_date = start_time, end_time
+        self._daily_load_and_save(self.file_pro)
+
+    def load_merge(self, start_time, end_time):
+        self.file_pro.start_date, self.file_pro.end_date = start_time, end_time
+        self._merge_and_save(self.file_pro)
+        
     def _load(self, start_end_fun, total=100):
         for i in range(1, total):
-            # for i in range(total, 0, -1):
             try:
                 self.file_pro.start_date, self.file_pro.end_date = start_end_fun(-i)
                 self._daily_load_and_save(self.file_pro)
